CElement class

Inheritance
Mixed-in types
Annotations

Constructors

CElement({String? name, String? flagUri, String? code, String? dialCode})

Properties

code ↔ String?
the country code (IT,AF..)
getter/setter pairinherited
dialCode ↔ String?
the dial code (+39,+93..)
getter/setter pairinherited
flagUri ↔ String?
the flag of the country
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
the name of the country
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCountryStringOnly() → String
inherited
toLongString() → String
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited